@@ -44,6 +44,7 @@
 #pod
 #pod         while ( $cond ) {
 #pod             do_something_else or $self->log_error( 'error message' ) and next;
+#pod             ...;
 #pod         };
 #pod
 #pod         $self->log_errors_in_file(
@@ -52,7 +53,7 @@
 #pod             5 => 'another error message',   # Error at file line 5.
 #pod         );
 #pod
-#pod         $self->abort_if_error( 'errors found' );
+#pod         $self->abort_if_errors( 'errors found' );
 #pod     };
 #pod
 #pod     __PACKAGE__->meta->make_immutable;
@@ -80,7 +81,7 @@ use Moose::Role;
 use namespace::autoclean;
 
 # ABSTRACT: Have error logging capabilities in your Dist::Zilla plugin
-our $VERSION = 'v0.8.0'; # VERSION
+our $VERSION = 'v0.9.0'; # VERSION
 
 requires qw{ log };
 
@@ -113,8 +114,9 @@ has error_count => (
 #pod This method calls C<log> method, passing all the arguments, and increments value of C<error_count>
 #pod attribute. The method returns true value, so can be used in following constructs:
 #pod
-#pod     while ( … ) {
+#pod     while ( ... ) {
 #pod         do_something or $self->log_error( 'message' ) and next;
+#pod         ...
 #pod     };
 #pod
 #pod =cut
@@ -142,40 +144,47 @@ sub log_error {                         ## no critic ( RequireArgUnpacking )
 #pod drawback|https://github.com/rjbs/Dist-Zilla/issues/397>: in contrast to C<log_fatal>, C<abort>
 #pod guarantees the message (which can be quite long) appears on the screen only once.
 #pod
-#pod The method log the message (via C<log>), then flush C<STDOUT>, then C<die>s with short message
-#pod C<"Aborting...\n">.
+#pod The method log the message (via C<log>), then flush C<STDOUT>, then throws an exception of
+#pod C<Dist::Zilla::Role::ErrorLogger::Exception::Abort> class (which being stringified gives short
+#pod message C<"Aborting...\n">).
 #pod
 #pod =cut
 
-sub abort {                             ## no critic ( RequireArgUnpacking )
+sub abort {                             ## no critic ( RequireArgUnpacking, RequireFinalReturn )
     my $self = shift( @_ );
     if ( @_ ) {
         $self->log( @_ );
     };
     STDOUT->flush();
-    die( "Aborting...\n" );
+    Dist::Zilla::Role::ErrorLogger::Exception::Abort->throw();
 };
 
 # --------------------------------------------------------------------------------------------------
 
 #pod =method abort_if_error
 #pod
-#pod     $self->abort_if_error( @items );
-#pod     $self->abort_if_error( \%args, @items );
+#pod =method abort_if_errors
+#pod
+#pod     $self->abort_if_errors( @items );
+#pod     $self->abort_if_errors( \%args, @items );
 #pod
 #pod If there was any errors (i. e. C<error_count> is greater than zero), the logs all the arguments and
 #pod aborts execution. Both actions (logging and aborting) are implemented by calling C<abort>.
 #pod
+#pod C<abort_if_error> is an alias for C<abort_if_errors>.
+#pod
 #pod =cut
 
-sub abort_if_error {                    ## no critic ( RequireArgUnpacking )
+sub abort_if_errors {                   ## no critic ( RequireArgUnpacking )
     my $self = shift( @_ );
     if ( $self->error_count ) {
-        $self->abort( @_  );
+        $self->abort( @_ );
     };
     return;
 };
 
+*abort_if_error = \&abort_if_errors;
+
 # --------------------------------------------------------------------------------------------------
 
 #pod =method log_errors_in_file
@@ -302,6 +311,27 @@ sub log_errors_in_file {
 
 # --------------------------------------------------------------------------------------------------
 
+## no critic ( ProhibitMultiplePackages )
+
+package Dist::Zilla::Role::ErrorLogger::Exception::Abort;
+
+use strict;
+use warnings;
+
+## no critic ( ProhibitReusedNames )
+# ABSTRACT: Exception class which C<ErrorLogger> throws to abort C<Dist::Zilla>
+our $VERSION = 'v0.9.0'; # VERSION
+## critic ( ProhibitReusedNames )
+
+use overload '""' => sub { return "Aborting...\n"; };
+
+sub throw {
+    my ( $class ) = @_;
+    die bless( {} => $class );          ## no critic ( RequireCarping )
+};
+
+# --------------------------------------------------------------------------------------------------
+
 1;
 
 # --------------------------------------------------------------------------------------------------
@@ -333,11 +363,11 @@ sub log_errors_in_file {
 #pod =head1 SEE ALSO
 #pod
 #pod =for :list
-#pod = L<Dist::Zilla>
-#pod = L<Dist::Zilla::Role>
-#pod = L<Dist::Zilla::Plugin>
-#pod = L<Log::Dispatchouli>
-#pod = L<String::Flogger>
+#pod =   L<Dist::Zilla>
+#pod =   L<Dist::Zilla::Role>
+#pod =   L<Dist::Zilla::Plugin>
+#pod =   L<Log::Dispatchouli>
+#pod =   L<String::Flogger>
 #pod
 #pod =head1 COPYRIGHT AND LICENSE
 #pod
@@ -352,19 +382,31 @@ sub log_errors_in_file {
 #pod
 #pod =cut
 
-# doc/what.pod #
+#   - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+#
+#   file: doc/what.pod
+#
+#   This file is part of perl-Dist-Zilla-Role-ErrorLogger.
+#
+#   - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
 #pod =encoding UTF-8
 #pod
 #pod =head1 WHAT?
 #pod
 #pod C<Dist-Zilla-Role-ErrorLogger> is a C<Dist::Zilla> role. It provides C<log_error>, C<abort>, and
-#pod C<abort_if_error> methods to consuming plugins.
+#pod C<abort_if_errors> methods to consuming plugins.
 #pod
 #pod =cut
 
 # end of file #
-# doc/why.pod #
+#   - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+#
+#   file: doc/why.pod
+#
+#   This file is part of perl-Dist-Zilla-Role-ErrorLogger.
+#
+#   - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
 #pod =encoding UTF-8
 #pod
@@ -379,9 +421,9 @@ sub log_errors_in_file {
 #pod Collect error messages in an array, then report all the errors with single C<log_fatal> call:
 #pod
 #pod     my @errors;
-#pod     …
-#pod     push( @errors, … );
-#pod     …
+#pod     ...
+#pod     push( @errors, ... );
+#pod     ...
 #pod     if ( @errors ) {
 #pod         $self->log_fatal( join( "\n", @errors ) );
 #pod     };
@@ -394,10 +436,10 @@ sub log_errors_in_file {
 #pod errors, and calling C<log_fatal> once at the end:
 #pod
 #pod     my $error_count = 0;
-#pod     …
+#pod     ...
 #pod     $self->log( 'error' );
 #pod     ++ $error_count;
-#pod     …
+#pod     ...
 #pod     if ( $error_count ) {
 #pod         $self->log_fatal( 'Aborting...' );
 #pod     };
@@ -406,10 +448,10 @@ sub log_errors_in_file {
 #pod C<Dist-Zilla-Role-ErrorLogger> role automates it, making plugin code shorter and more readable:
 #pod
 #pod     with 'Dist-Zilla-Role-ErrorLogger';
-#pod     …
+#pod     ...
 #pod     $self->log_error( 'error' );
-#pod     …
-#pod     $self->abort_if_error();
+#pod     ...
+#pod     $self->abort_if_errors();
 #pod
 #pod =cut
 
@@ -430,12 +472,12 @@ Dist::Zilla::Role::ErrorLogger - Have error logging capabilities in your Dist::Z
 
 =head1 VERSION
 
-Version v0.8.0, released on 2015-10-24 17:27 UTC.
+Version v0.9.0, released on 2015-10-26 21:04 UTC.
 
 =head1 WHAT?
 
 C<Dist-Zilla-Role-ErrorLogger> is a C<Dist::Zilla> role. It provides C<log_error>, C<abort>, and
-C<abort_if_error> methods to consuming plugins.
+C<abort_if_errors> methods to consuming plugins.
 
 This is C<Dist::Zilla::Role::ErrorLogger> role documentation. Read this if you want to
 have error logging capabilities in your Dist::Zilla plugin.
@@ -457,6 +499,7 @@ have error logging capabilities in your Dist::Zilla plugin.
 
         while ( $cond ) {
             do_something_else or $self->log_error( 'error message' ) and next;
+            ...;
         };
 
         $self->log_errors_in_file(
@@ -465,7 +508,7 @@ have error logging capabilities in your Dist::Zilla plugin.
             5 => 'another error message',   # Error at file line 5.
         );
 
-        $self->abort_if_error( 'errors found' );
+        $self->abort_if_errors( 'errors found' );
     };
 
     __PACKAGE__->meta->make_immutable;
@@ -497,8 +540,9 @@ C<Int>, read-only. Number of logged errors (i. e. number of made C<log_error> ca
 This method calls C<log> method, passing all the arguments, and increments value of C<error_count>
 attribute. The method returns true value, so can be used in following constructs:
 
-    while ( … ) {
+    while ( ... ) {
         do_something or $self->log_error( 'message' ) and next;
+        ...
     };
 
 =head2 abort
@@ -510,17 +554,22 @@ This is an attempt to workaround L<C<log_fatal>
 drawback|https://github.com/rjbs/Dist-Zilla/issues/397>: in contrast to C<log_fatal>, C<abort>
 guarantees the message (which can be quite long) appears on the screen only once.
 
-The method log the message (via C<log>), then flush C<STDOUT>, then C<die>s with short message
-C<"Aborting...\n">.
+The method log the message (via C<log>), then flush C<STDOUT>, then throws an exception of
+C<Dist::Zilla::Role::ErrorLogger::Exception::Abort> class (which being stringified gives short
+message C<"Aborting...\n">).
 
 =head2 abort_if_error
 
-    $self->abort_if_error( @items );
-    $self->abort_if_error( \%args, @items );
+=head2 abort_if_errors
+
+    $self->abort_if_errors( @items );
+    $self->abort_if_errors( \%args, @items );
 
 If there was any errors (i. e. C<error_count> is greater than zero), the logs all the arguments and
 aborts execution. Both actions (logging and aborting) are implemented by calling C<abort>.
 
+C<abort_if_error> is an alias for C<abort_if_errors>.
+
 =head2 log_errors_in_file
 
 The method intended to report errors against a file. It prints file name (and colon after it), then
@@ -566,9 +615,9 @@ used, obviously. There are few alternatives:
 Collect error messages in an array, then report all the errors with single C<log_fatal> call:
 
     my @errors;
-    …
-    push( @errors, … );
-    …
+    ...
+    push( @errors, ... );
+    ...
     if ( @errors ) {
         $self->log_fatal( join( "\n", @errors ) );
     };
@@ -581,10 +630,10 @@ Another approach is reporting each error immediately with C<log>, counting numbe
 errors, and calling C<log_fatal> once at the end:
 
     my $error_count = 0;
-    …
+    ...
     $self->log( 'error' );
     ++ $error_count;
-    …
+    ...
     if ( $error_count ) {
         $self->log_fatal( 'Aborting...' );
     };
@@ -593,10 +642,10 @@ This works, but incrementing the counter after each C<log> call is boring and er
 C<Dist-Zilla-Role-ErrorLogger> role automates it, making plugin code shorter and more readable:
 
     with 'Dist-Zilla-Role-ErrorLogger';
-    …
+    ...
     $self->log_error( 'error' );
-    …
-    $self->abort_if_error();
+    ...
+    $self->abort_if_errors();
 
 =for test_synopsis my ( $cond, $file );
 sub Dist::Zilla::Plugin::YourPlugin::do_something;
